# defining global variables and functions to appease R CMD Check

utils::globalVariables(
  names = c(
    ".",
    ".wt",
    "perc",
    "N",
    "NN",
    "n",
    "samplenumb",
    "correct",
    "TheMean",
    "TheSEM",
    "TheSD",
    "CIMuliplier",
    "LowerBound",
    "UpperBound",
    "p.value",
    "term",
    "outcome",
    "splitrule",
    "df",
    "chisq",
    "method",
    "NodeN",
    "nodeID",
    "adjustedp",
    "parent",
    "ruletext",
    "split.variable",
    "rawpvalue",
    "statistic",
    "parameter",
    "support",
    "logged",
    "sensible",
    "astext",
    "xmin",
    "xmax",
    "ymin",
    "ymax",
    "pct",
    ".",
    "alias",
    "coef",
    "coefficients",
    "deviance",
    "df.residual",
    "makeHypothesis",
    "model.frame",
    "model.matrix",
    "model.response",
    "pchisq", 
    "setNames", 
    "terms", 
    "vcov",
    "model",
    "error",
    "bf"
  ),
  package = "CGPfunctions",
  add = FALSE
)